<?php
add_action('after_setup_theme', 'silverblue_add_editor_styles');
add_action('after_setup_theme', 'silverblue_setup');

function silverblue_setup()
{
	load_theme_textdomain('silverblue', get_template_directory() . '/languages');
	$args = array(
		'flex-width' => true,
		'width' => 950,
		'flex-height' => true,
		'height' => 348,
		'default-image' => get_template_directory_uri() . '/images/silver-blue-and-gold-sky.jpg',
		'uploads' => true
	);
	add_theme_support('custom-header', $args);
	add_theme_support('automatic-feed-links');
	add_theme_support('post-thumbnails');
	add_theme_support('custom-background');
	global $content_width;
	if (!isset($content_width)) $content_width = 438;
	register_nav_menus(array(
		'main' => __('Main Menu', 'silverblue')
	));
}

function silverblue_add_editor_styles()
{
	add_editor_style('custom-editor-style.css');
}

add_action('wp_enqueue_scripts', 'silverblue_load_scripts');

function silverblue_load_scripts()
{
	wp_enqueue_style('style', get_stylesheet_uri());
}

add_action('comment_form_before', 'silverblue_enqueue_comment_reply_script');

function silverblue_enqueue_comment_reply_script()
{
	if (get_option('thread_comments'))
	{
		wp_enqueue_script('comment-reply');
	}
}

add_filter('the_title', 'silverblue_title');

function silverblue_title($title)
{
	if ($title == '')
	{
		return '&rarr;';
	}
	else
	{
		return $title;
	}
}

function silverblue_customize_register($wp_customize)
{
	$wp_customize->add_setting('menubar_bg', array(
		'flex-width' => true,
		'width' => 2,
		'flex-height' => true,
		'height' => 35,
		'default-image' => get_template_directory_uri() . '/images/menubar-graphic.png',
		'default-repeat' => 'x',
		'default-position-x' => '',
		'uploads' => true,
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_section('silverblue_menubar_bg', array(
		'title' => __('Menubar Background', 'silverblue') ,
		'priority' => 50
	));
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'logo', array(
		'label' => __('Upload a background image', 'silverblue') ,
		'section' => 'silverblue_menubar_bg',
		'settings' => 'menubar_bg',
		'context' => 'normal',
	)));
	$wp_customize->add_setting('dark_color', array(
		'default' => '#225a93',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'dark_color', array(
		'label' => 'Dark Accent Color',
		'section' => 'colors',
		'settings' => 'dark_color'
	)));
	$wp_customize->add_setting('light_color', array(
		'default' => '#fdd8a5',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'light_color', array(
		'label' => 'Light Accent Color',
		'section' => 'colors',
		'settings' => 'light_color'
	)));
}

add_action('customize_register', 'silverblue_customize_register');

function silverblue_customize_css()
{
?>
         <style type="text/css">
#header, #footer, .entry-content table th, #menutop { background-color:<?php
	echo get_theme_mod('dark_color', '#225a93');
?>; }
             .entry-title, .entry-title a, h3, .widget-title { color:<?php
	echo get_theme_mod('dark_color', '#225a93');
?> ; } 
             .entry-content legend, #top-search input.find, a.comment-reply-link, #sidebar #searchsubmit, #sidebar2 #searchsubmit, .entry-content table th, .entry-content table th a:link, .entry-content table th a:visited, .entry-content table th a:active, .entry-content table th a:hover, #content submit, #commentform #submit, #access li a, #access ul ul a, #access li:hover > a, #access a:focus, #access a:link,
#access a:visited, #access a:active, #access a:hover, #copyright a:link, #copyright a:visited, #copyright a:active, #copyright a:hover, #copyright, #site-title, #site-title a:link, #site-title a:visited, #site-title a:active, #site-title a:hover, #site-description, #content input.button, #commentform input.button    {
    color:<?php
	echo get_theme_mod('light_color', '#fdd8a5');
?> ;
}
#access ul ul a, #access li li { border-bottom: 1px solid <?php
	echo get_theme_mod('light_color', '#fdd8a5');
?> ;}
#top-search .searchbox { background-color: <?php
	echo get_theme_mod('light_color', '#fdd8a5');
?>; }
#menutop, a.comment-reply-link,
    #sidebar #searchsubmit,
    #sidebar2 #searchsubmit,
    #content #submit,
    #commentform #submit,
    #content input.button,
    #commentform input.button,
    .comments-list li div.reply a,
    #top-search input.find {
      background: url( <?php
	echo get_theme_mod('menubar_bg', get_template_directory_uri() . '/images/menubar-graphic.png'); ?> ) repeat-x bottom !important;
    }

</style>
    <?php
}

add_action('wp_head', 'silverblue_customize_css');
add_filter('wp_title', 'silverblue_filter_wp_title');

function silverblue_filter_wp_title($title)
{
	return $title . esc_attr(get_bloginfo('name'));
}

add_action('widgets_init', 'silverblue_widgets_init');

function silverblue_widgets_init()
{
	register_sidebar(array(
		'name' => __('Primary Widget Area', 'silverblue') ,
		'id' => 'primary-widget-area',
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => "</li>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>'
	));
	register_sidebar(array(
		'name' => __('Secondary Widget Area', 'silverblue') ,
		'id' => 'secondary-widget-area',
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => "</li>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>'
	));
}

function silverblue_custom_pings($comment)
{
	$GLOBALS['comment'] = $comment;
?>
<li <?php
	comment_class();
?> id="li-comment-<?php
	comment_ID();
?>"><?php
	echo comment_author_link();
?></li>
<?php
}

add_filter('get_comments_number', 'silverblue_comments_number');

function silverblue_comments_number($count)
{
	if (!is_admin())
	{
		global $id;
		$comments_by_type = separate_comments(get_comments('status=approve&post_id=' . $id));
		return count($comments_by_type['comment']);
	}
	else
	{
		return $count;
	}
}